pub struct LocalizedSearchPlugin { /* private fields */ }Expand description
Variant of SearchPlugin that injects the widget with caller-supplied
localized SearchLabels.
Example
use ssg::plugin::PluginManager;
use ssg::search::{LocalizedSearchPlugin, SearchLabels};
let mut pm = PluginManager::new();
pm.register(LocalizedSearchPlugin::new(SearchLabels::french()));Implementations
Sourceimpl LocalizedSearchPlugin
impl LocalizedSearchPlugin
Sourcepub const fn new(labels: SearchLabels) -> Self
pub const fn new(labels: SearchLabels) -> Self
Create a new localized search plugin with the given labels.
Examples
use ssg::plugin::Plugin;
use ssg::search::{LocalizedSearchPlugin, SearchLabels};
let p = LocalizedSearchPlugin::new(SearchLabels::english());
assert_eq!(p.name(), "search");Trait Implementations
Sourceimpl Clone for LocalizedSearchPlugin
impl Clone for LocalizedSearchPlugin
Sourcefn clone(&self) -> LocalizedSearchPlugin
fn clone(&self) -> LocalizedSearchPlugin
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LocalizedSearchPlugin
impl Debug for LocalizedSearchPlugin
Sourceimpl Plugin for LocalizedSearchPlugin
impl Plugin for LocalizedSearchPlugin
Sourcefn has_transform(&self) -> bool
fn has_transform(&self) -> bool
Returns
true if this plugin implements transform_html.
Override to true to opt in to the fused transform pass.Sourcefn transform_html(
&self,
html: &str,
_path: &Path,
ctx: &PluginContext,
) -> Result<String, SsgError>
fn transform_html( &self, html: &str, _path: &Path, ctx: &PluginContext, ) -> Result<String, SsgError>
Per-file HTML transform hook — called once per HTML file during
the fused transform pass. Read more
Sourcefn after_compile(&self, ctx: &PluginContext) -> Result<(), SsgError>
fn after_compile(&self, ctx: &PluginContext) -> Result<(), SsgError>
Called after site compilation completes. Read more
Sourcefn before_compile(&self, _ctx: &PluginContext) -> Result<(), SsgError>
fn before_compile(&self, _ctx: &PluginContext) -> Result<(), SsgError>
Called before site compilation begins. Read more
Sourcefn needs_all_files(&self) -> bool
fn needs_all_files(&self) -> bool
Returns
true if this plugin must always observe the full
cache.html_files() list — even during --incremental
rebuilds that only invalidated a handful of pages. Read moreAuto Trait Implementations
impl Freeze for LocalizedSearchPlugin
impl RefUnwindSafe for LocalizedSearchPlugin
impl Send for LocalizedSearchPlugin
impl Sync for LocalizedSearchPlugin
impl Unpin for LocalizedSearchPlugin
impl UnsafeUnpin for LocalizedSearchPlugin
impl UnwindSafe for LocalizedSearchPlugin